@@ -159,9 +159,9 @@ indicates it is enabled.")
 
 ;; cut and paste
 
-(define-key pc-select-map [(shift delete)]	'x-kill-primary-selection)
-(define-key pc-select-map [(shift insert)]	'x-yank-clipboard-selection)
-(define-key pc-select-map [(control insert)]	'x-copy-primary-selection)
+(define-key pc-select-map [(shift delete)]	'kill-primary-selection)
+(define-key pc-select-map [(shift insert)]	'yank-clipboard-selection)
+(define-key pc-select-map [(control insert)]	'copy-primary-selection)
 
 ;; this defun makes sure mark is set.
 
